# coding=utf-8
# pylint: disable=useless-super-delegation

import datetime
from typing import Any, Mapping, TYPE_CHECKING, overload

from .._utils.model_base import Model as _Model, rest_field

if TYPE_CHECKING:
    from .. import models as _models


class BytesProperty(_Model):
    """Template type for testing models with nullable property. Pass in the type of the property you
    are looking for.

    :ivar required_property: Required property. Required.
    :vartype required_property: str
    :ivar nullable_property: Property. Required.
    :vartype nullable_property: bytes
    """

    required_property: str = rest_field(
        name="requiredProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Required property. Required."""
    nullable_property: bytes = rest_field(
        name="nullableProperty", visibility=["read", "create", "update", "delete", "query"], format="base64"
    )
    """Property. Required."""

    @overload
    def __init__(
        self,
        *,
        required_property: str,
        nullable_property: bytes,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class CollectionsByteProperty(_Model):
    """Model with collection bytes properties.

    :ivar required_property: Required property. Required.
    :vartype required_property: str
    :ivar nullable_property: Property. Required.
    :vartype nullable_property: list[bytes]
    """

    required_property: str = rest_field(
        name="requiredProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Required property. Required."""
    nullable_property: list[bytes] = rest_field(
        name="nullableProperty", visibility=["read", "create", "update", "delete", "query"], format="base64"
    )
    """Property. Required."""

    @overload
    def __init__(
        self,
        *,
        required_property: str,
        nullable_property: list[bytes],
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class CollectionsModelProperty(_Model):
    """Model with collection models properties.

    :ivar required_property: Required property. Required.
    :vartype required_property: str
    :ivar nullable_property: Property. Required.
    :vartype nullable_property: list[~typetest.property.nullable.models.InnerModel]
    """

    required_property: str = rest_field(
        name="requiredProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Required property. Required."""
    nullable_property: list["_models.InnerModel"] = rest_field(
        name="nullableProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Property. Required."""

    @overload
    def __init__(
        self,
        *,
        required_property: str,
        nullable_property: list["_models.InnerModel"],
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class CollectionsStringProperty(_Model):
    """Model with collection string properties.

    :ivar required_property: Required property. Required.
    :vartype required_property: str
    :ivar nullable_property: Property. Required.
    :vartype nullable_property: list[str]
    """

    required_property: str = rest_field(
        name="requiredProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Required property. Required."""
    nullable_property: list[str] = rest_field(
        name="nullableProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Property. Required."""

    @overload
    def __init__(
        self,
        *,
        required_property: str,
        nullable_property: list[str],
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class DatetimeProperty(_Model):
    """Model with a datetime property.

    :ivar required_property: Required property. Required.
    :vartype required_property: str
    :ivar nullable_property: Property. Required.
    :vartype nullable_property: ~datetime.datetime
    """

    required_property: str = rest_field(
        name="requiredProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Required property. Required."""
    nullable_property: datetime.datetime = rest_field(
        name="nullableProperty", visibility=["read", "create", "update", "delete", "query"], format="rfc3339"
    )
    """Property. Required."""

    @overload
    def __init__(
        self,
        *,
        required_property: str,
        nullable_property: datetime.datetime,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class DurationProperty(_Model):
    """Model with a duration property.

    :ivar required_property: Required property. Required.
    :vartype required_property: str
    :ivar nullable_property: Property. Required.
    :vartype nullable_property: ~datetime.timedelta
    """

    required_property: str = rest_field(
        name="requiredProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Required property. Required."""
    nullable_property: datetime.timedelta = rest_field(
        name="nullableProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Property. Required."""

    @overload
    def __init__(
        self,
        *,
        required_property: str,
        nullable_property: datetime.timedelta,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class InnerModel(_Model):
    """Inner model used in collections model property.

    :ivar property: Inner model property. Required.
    :vartype property: str
    """

    property: str = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """Inner model property. Required."""

    @overload
    def __init__(
        self,
        *,
        property: str,  # pylint: disable=redefined-builtin
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class StringProperty(_Model):
    """Template type for testing models with nullable property. Pass in the type of the property you
    are looking for.

    :ivar required_property: Required property. Required.
    :vartype required_property: str
    :ivar nullable_property: Property. Required.
    :vartype nullable_property: str
    """

    required_property: str = rest_field(
        name="requiredProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Required property. Required."""
    nullable_property: str = rest_field(
        name="nullableProperty", visibility=["read", "create", "update", "delete", "query"]
    )
    """Property. Required."""

    @overload
    def __init__(
        self,
        *,
        required_property: str,
        nullable_property: str,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

import os
import time
import asyncio

from devtools_testutils.perfstress_tests import PerfStressTest


# Used for logging every step and property of the perf test
class LogTest(PerfStressTest):
    _logged_global_completed_operations = 0

    start_time = time.time()

    def __init__(self, arguments):
        super().__init__(arguments)
        self._seconds_per_operation = 1.0 / (self._parallel_index + 1)
        self._logged_completed_operations = 0
        self.log("__init__()")

    async def global_setup(self):
        await super().global_setup()
        self.log("global_setup()")

    async def setup(self):
        await super().setup()
        self.log("setup()")

    def run_sync(self):
        time.sleep(self._seconds_per_operation)
        self._logged_completed_operations += 1
        type(self)._logged_global_completed_operations += 1

    async def run_async(self):
        await asyncio.sleep(self._seconds_per_operation)
        self._logged_completed_operations += 1
        type(self)._logged_global_completed_operations += 1

    async def cleanup(self):
        await super().cleanup()
        self.log(f"cleanup() - Completed Operations: {self._logged_completed_operations}")

    async def global_cleanup(self):
        await super().global_cleanup()
        self.log(f"global_cleanup() - Global Completed Operations: {self._logged_global_completed_operations}")

    def log(self, message):
        print(
            f"[{(time.time() - type(self).start_time):.3f}] [PID: {os.getpid()}] [Parallel: {self._parallel_index}] {message}"
        )



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from devtools_testutils import recorded_by_proxy
from testpreparer import UnionClientTestBase, UnionPreparer


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestUnionIntsOnlyOperations(UnionClientTestBase):
    @UnionPreparer()
    @recorded_by_proxy
    def test_ints_only_get(self, union_endpoint):
        client = self.create_client(endpoint=union_endpoint)
        response = client.ints_only.get()

        # please add some check logic here by yourself
        # ...

    @UnionPreparer()
    @recorded_by_proxy
    def test_ints_only_send(self, union_endpoint):
        client = self.create_client(endpoint=union_endpoint)
        response = client.ints_only.send(
            body={"prop": 1},
            prop=1,
        )

        # please add some check logic here by yourself
        # ...



# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------
"""
DESCRIPTION:
    This sample demonstrates how to get image embeddings vector for
    an input image, using an asynchronous client.

    This sample assumes the AI model is hosted on a Serverless API or
    Managed Compute endpoint. For GitHub Models or Azure OpenAI endpoints,
    the client constructor needs to be modified. See package documentation:
    https://github.com/Azure/azure-sdk-for-python/blob/main/sdk/ai/azure-ai-inference/README.md#key-concepts

USAGE:
    python sample_image_embeddings_async.py

    Set these two environment variables before running the sample:
    1) AZURE_AI_IMAGE_EMBEDDINGS_ENDPOINT - Your endpoint URL, in the form 
        https://<your-deployment-name>.<your-azure-region>.models.ai.azure.com
        where `your-deployment-name` is your unique AI Model deployment name, and
        `your-azure-region` is the Azure region where your model is deployed.
    2) AZURE_AI_IMAGE_EMBEDDINGS_KEY - Your model key. Keep it secret.
"""
import asyncio


async def sample_image_embeddings_async():
    import os

    try:
        endpoint = os.environ["AZURE_AI_IMAGE_EMBEDDINGS_ENDPOINT"]
        key = os.environ["AZURE_AI_IMAGE_EMBEDDINGS_KEY"]
    except KeyError:
        print("Missing environment variable 'AZURE_AI_IMAGE_EMBEDDINGS_ENDPOINT' or 'AZURE_AI_IMAGE_EMBEDDINGS_KEY'")
        print("Set them before running this sample.")
        exit()

    from azure.ai.inference.aio import ImageEmbeddingsClient
    from azure.ai.inference.models import ImageEmbeddingInput
    from azure.core.credentials import AzureKeyCredential

    async with ImageEmbeddingsClient(endpoint=endpoint, credential=AzureKeyCredential(key)) as client:

        # Do a single image embeddings operation. Start the operation and get a Future object.
        response = await client.embed(input=[ImageEmbeddingInput.load(image_file="sample1.png", image_format="png")])

        print("Embeddings response:")
        for item in response.data:
            length = len(item.embedding)
            print(
                f"data[{item.index}]: length={length}, [{item.embedding[0]}, {item.embedding[1]}, "
                f"..., {item.embedding[length-2]}, {item.embedding[length-1]}]"
            )


async def main():
    await sample_image_embeddings_async()


if __name__ == "__main__":
    asyncio.run(main())



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------
"""Customize generated code here.

Follow our quickstart for examples: https://aka.ms/azsdk/python/dpcodegen/python/customize
"""
# coding: utf-8
import json
from typing import Any, Callable, Dict, IO, Mapping, Optional, TypeVar, Union, cast, overload, Generic, TYPE_CHECKING
from collections.abc import MutableMapping  # pylint:disable=import-error

from azure.core.exceptions import HttpResponseError
from azure.core.pipeline import PipelineResponse
from azure.core.polling import AsyncLROPoller, AsyncPollingMethod, AsyncNoPolling
from azure.core.polling.async_base_polling import AsyncLROBasePolling
from azure.core.rest import HttpRequest, AsyncHttpResponse
from azure.core.tracing.decorator_async import distributed_trace_async
from azure.core.utils import case_insensitive_dict
from azure.core.credentials import AzureKeyCredential
from azure.core.async_paging import AsyncItemPaged

from ._client import TextAnalysisClient as AnalysisTextClientGenerated
from .. import models as _models
from ..models import AnalyzeTextOperationState, TextActions
from .._utils.serialization import Serializer
from .._patch import _parse_operation_id

if TYPE_CHECKING:
    from azure.core.credentials_async import AsyncTokenCredential

JSON = MutableMapping[str, Any]
_Unset: Any = object()
T = TypeVar("T")
PollingReturnType_co = TypeVar("PollingReturnType_co", covariant=True)
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, AsyncHttpResponse], T, Dict[str, Any]], Any]]

_SERIALIZER = Serializer()
_SERIALIZER.client_side_validation = False


class AnalyzeTextAsyncLROPoller(AsyncLROPoller[PollingReturnType_co], Generic[PollingReturnType_co]):
    """Custom **async** poller that returns ``PollingReturnType_co`` and exposes operation metadata."""

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)
        self._last_state: Optional[AnalyzeTextOperationState] = None  # set by deserializer

    # internal: called by the deserializer to update details()
    def _record_state_for_details(self, state: AnalyzeTextOperationState) -> None:
        self._last_state = state

    @property
    def details(self) -> Mapping[str, Any]:
        """Metadata associated with the long-running operation.

        :return: A mapping with keys like ``operation_id`` and, when available,
            ``status``, ``job_id``, ``display_name``, ``created_at``,
            ``last_updated_at``, ``expires_on``, ``statistics``,
            ``errors``, and ``next_link``.
        :rtype: Mapping[str, Any]
        """
        try:
            headers = getattr(
                self.polling_method(), "_initial_response"
            ).http_response.headers  # type: ignore[attr-defined]
            op_loc = headers.get("Operation-Location") or headers.get("operation-location")
        except (AttributeError, TypeError):
            op_loc = None

        info: Dict[str, Any] = {"operation_id": _parse_operation_id(op_loc)}
        if self._last_state is not None:
            s = self._last_state
            info.update(
                {
                    "status": s.status,
                    "job_id": s.job_id,
                    "display_name": s.display_name,
                    "created_at": s.created_at,
                    "last_updated_at": s.last_updated_at,
                    "expires_on": s.expires_on,
                    "statistics": s.statistics,
                    "errors": s.errors,
                    "next_link": s.next_link,
                }
            )
        return info

    @classmethod
    def from_continuation_token(
        cls,
        polling_method: AsyncPollingMethod[PollingReturnType_co],
        continuation_token: str,
        **kwargs: Any,
    ) -> "AnalyzeTextAsyncLROPoller[PollingReturnType_co]":
        client, initial_response, deserialization_callback = polling_method.from_continuation_token(
            continuation_token, **kwargs
        )
        return cls(client, initial_response, deserialization_callback, polling_method)


class TextAnalysisClient(AnalysisTextClientGenerated):
    """**Async** client for Text Analysis APIs."""

    def __init__(
        self,
        endpoint: str,
        credential: Union[AzureKeyCredential, "AsyncTokenCredential"],
        *,
        api_version: Optional[str] = None,
        **kwargs: Any,
    ) -> None:
        """Create a TextAnalysisClient.

        :param endpoint: Supported Cognitive Services endpoint.
        :type endpoint: str
        :param credential: Key or token credential.
        :type credential: ~azure.core.credentials.AzureKeyCredential or ~azure.core.credentials.AsyncTokenCredential
        :keyword api_version: The API version to use for this operation. Default value is
         ``"2025-05-15-preview"``. Note that overriding this default value may result in unsupported
         behavior.
        :paramtype api_version: str
        """
        if api_version is not None:
            kwargs["api_version"] = api_version
        super().__init__(endpoint=endpoint, credential=credential, **kwargs)

    @overload # type: ignore[override]
    async def begin_analyze_text_job(
        self,
        *,
        text_input: _models.MultiLanguageTextInput,
        actions: list[_models.AnalyzeTextOperationAction],
        content_type: str = "application/json",
        display_name: Optional[str] = None,
        default_language: Optional[str] = None,
        cancel_after: Optional[float] = None,
        **kwargs: Any,
    ) -> AnalyzeTextAsyncLROPoller[AsyncItemPaged["TextActions"]]:
        """Submit a collection of text documents for analysis. Specify one or more unique tasks to be
        executed as a long-running operation.

        :keyword text_input: Contains the input to be analyzed. Required.
        :paramtype text_input: ~azure.ai.textanalytics.models.MultiLanguageTextInput
        :keyword actions: List of tasks to be performed as part of the LRO. Required.
        :paramtype actions: list[~azure.ai.textanalytics.models.AnalyzeTextOperationAction]
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is ``"application/json"``.
        :paramtype content_type: str
        :keyword display_name: Name for the task. Default value is ``None``.
        :paramtype display_name: str
        :keyword default_language: Default language to use for records requesting automatic language
         detection. Default value is ``None``.
        :paramtype default_language: str
        :keyword cancel_after: Optional duration in seconds after which the job will be canceled if not
         completed. Default value is ``None``.
        :paramtype cancel_after: float
        :return: A poller whose ``result()`` yields ``AsyncItemPaged[TextActions]`` and exposes metadata via
         ``.details``.
        :rtype: ~azure.ai.textanalytics.AnalyzeTextAsyncLROPoller[
                ~azure.core.async_paging.AsyncItemPaged[~azure.ai.textanalytics.models.TextActions]]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def begin_analyze_text_job( # type: ignore[override]
        self, body: JSON, *, content_type: str = "application/json", **kwargs: Any
    ) -> AnalyzeTextAsyncLROPoller[AsyncItemPaged["TextActions"]]:
        """Submit a collection of text documents for analysis. Specify one or more unique tasks to be
        executed as a long-running operation.

        :param body: Required.
        :type body: JSON
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is ``"application/json"``.
        :paramtype content_type: str
        :return: A poller whose ``result()`` yields ``AsyncItemPaged[TextActions]`` and exposes metadata via
         ``.details``.
        :rtype: ~azure.ai.textanalytics.AnalyzeTextAsyncLROPoller[
                ~azure.core.async_paging.AsyncItemPaged[~azure.ai.textanalytics.models.TextActions]]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    async def begin_analyze_text_job( # type: ignore[override]
        self, body: IO[bytes], *, content_type: str = "application/json", **kwargs: Any
    ) -> AnalyzeTextAsyncLROPoller[AsyncItemPaged["TextActions"]]:
        """Submit a collection of text documents for analysis. Specify one or more unique tasks to be
        executed as a long-running operation.

        :param body: Required.
        :type body: IO[bytes]
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is ``"application/json"``.
        :paramtype content_type: str
        :return: A poller whose ``result()`` yields ``AsyncItemPaged[TextActions]`` and exposes metadata via
         ``.details``.
        :rtype: ~azure.ai.textanalytics.AnalyzeTextAsyncLROPoller[
                ~azure.core.async_paging.AsyncItemPaged[~azure.ai.textanalytics.models.TextActions]]
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace_async
    async def begin_analyze_text_job(  # type: ignore[override]
        self,
        body: Union[JSON, IO[bytes]] = _Unset,
        *,
        text_input: _models.MultiLanguageTextInput = _Unset,
        actions: list[_models.AnalyzeTextOperationAction] = _Unset,
        display_name: Optional[str] = None,
        default_language: Optional[str] = None,
        cancel_after: Optional[float] = None,
        **kwargs: Any,
    ) -> AnalyzeTextAsyncLROPoller[AsyncItemPaged["TextActions"]]:
        """Submit a collection of text documents for analysis. Specify one or more unique tasks to be
        executed as a long-running operation.

        :param body: Is either a JSON type or a IO[bytes] type. Required.
        :type body: JSON or IO[bytes]
        :keyword text_input: Contains the input to be analyzed. Required.
        :paramtype text_input: ~azure.ai.textanalytics.models.MultiLanguageTextInput
        :keyword actions: List of tasks to be performed as part of the LRO. Required.
        :paramtype actions: list[~azure.ai.textanalytics.models.AnalyzeTextOperationAction]
        :keyword display_name: Name for the task. Default value is ``None``.
        :paramtype display_name: str
        :keyword default_language: Default language to use for records requesting automatic language
         detection. Default value is ``None``.
        :paramtype default_language: str
        :keyword cancel_after: Optional duration in seconds after which the job will be canceled if not
         completed. Default value is ``None``.
        :paramtype cancel_after: float
        :return: A poller whose ``result()`` yields ``AsyncItemPaged[TextActions]`` and exposes metadata via
         ``.details``.
        :rtype: ~azure.ai.textanalytics.AnalyzeTextAsyncLROPoller[
                ~azure.core.async_paging.AsyncItemPaged[~azure.ai.textanalytics.models.TextActions]]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = kwargs.pop("params", {}) or {}

        content_type: Optional[str] = kwargs.pop("content_type", _headers.pop("Content-Type", None))
        polling: Union[bool, AsyncPollingMethod[AsyncItemPaged["TextActions"]]] = kwargs.pop("polling", True)
        lro_delay = kwargs.pop("polling_interval", self._config.polling_interval)
        cont_token: Optional[str] = kwargs.pop("continuation_token", None)
        cls: ClsType[AsyncItemPaged["TextActions"]] = kwargs.pop("cls", None)
        kwargs.pop("error_map", None)

        path_format_arguments = {
            "Endpoint": self._serialize.url(  # type: ignore[attr-defined]
                "self._config.endpoint", self._config.endpoint, "str", skip_quote=True
            ),
        }

        async def _fetch_state_by_next_link(next_link: str) -> AnalyzeTextOperationState:
            req = HttpRequest("GET", next_link)
            resp = await self._client.send_request(req)  # type: ignore[attr-defined]
            if resp.status_code != 200:
                raise HttpResponseError(response=resp)
            data = json.loads(await resp.text())
            return AnalyzeTextOperationState(data)

        def _build_pager_from_state(
            state: AnalyzeTextOperationState,
        ) -> AsyncItemPaged["TextActions"]:
            async def extract_data(s: AnalyzeTextOperationState):
                next_link = s.next_link
                actions_payload: TextActions = s.actions
                return next_link, [actions_payload]

            async def get_next(token: Optional[str]) -> Optional[AnalyzeTextOperationState]:
                if token is None:
                    return state
                if not token:
                    return None
                return await _fetch_state_by_next_link(token)

            return AsyncItemPaged(get_next, extract_data)

        poller_holder: Dict[str, AnalyzeTextAsyncLROPoller[AsyncItemPaged["TextActions"]]] = {}

        def get_long_running_output(pipeline_response):
            final = pipeline_response.http_response
            if final.status_code == 200:
                data = json.loads(final.text())
                op_state = AnalyzeTextOperationState(data)

                poller_ref = poller_holder["poller"]
                poller_ref._record_state_for_details(op_state)  # pylint:disable=protected-access

                paged = _build_pager_from_state(op_state)
                return cls(pipeline_response, paged, {}) if cls else paged
            raise HttpResponseError(response=final)

        if polling is True:
            polling_method: AsyncPollingMethod[AsyncItemPaged["TextActions"]] = cast(
                AsyncPollingMethod[AsyncItemPaged["TextActions"]],
                AsyncLROBasePolling(lro_delay, path_format_arguments=path_format_arguments, **kwargs),
            )
        elif polling is False:
            polling_method = cast(AsyncPollingMethod[AsyncItemPaged["TextActions"]], AsyncNoPolling())
        else:
            polling_method = cast(AsyncPollingMethod[AsyncItemPaged["TextActions"]], polling)

        if cont_token:
            return AnalyzeTextAsyncLROPoller[AsyncItemPaged["TextActions"]].from_continuation_token(
                polling_method=polling_method,
                continuation_token=cont_token,
            )

        initial_kwargs = dict(  # pylint:disable=use-dict-literal
            text_input=text_input,
            actions=actions,
            display_name=display_name,
            default_language=default_language,
            cancel_after=cancel_after,
            content_type=content_type,
            cls=lambda x, y, z: x,  # passthrough raw pipeline response
            headers=_headers,
            params=_params,
            **kwargs,
        )
        if body is not _Unset and body is not None:
            initial_kwargs["body"] = body

        raw_result = await self._analyze_text_job_initial(**initial_kwargs)
        await raw_result.http_response.read()  # type: ignore[attr-defined]

        lro: AnalyzeTextAsyncLROPoller[AsyncItemPaged["TextActions"]] = AnalyzeTextAsyncLROPoller(
            self._client, raw_result, get_long_running_output, polling_method
        )
        poller_holder["poller"] = lro
        return lro


def patch_sdk():
    """Do not remove from this file.

    `patch_sdk` is a last resort escape hatch that allows you to do customizations
    you can't accomplish using the techniques described in
    https://aka.ms/azsdk/python/dpcodegen/python/customize
    """


__all__ = ["TextAnalysisClient", "AnalyzeTextAsyncLROPoller"]



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._models_py3 import AcceleratorAuthSetting
from ._models_py3 import AcceleratorBasicAuthSetting
from ._models_py3 import AcceleratorGitRepository
from ._models_py3 import AcceleratorPublicSetting
from ._models_py3 import AcceleratorSshSetting
from ._models_py3 import ActiveDeploymentCollection
from ._models_py3 import ApiPortalCustomDomainProperties
from ._models_py3 import ApiPortalCustomDomainResource
from ._models_py3 import ApiPortalCustomDomainResourceCollection
from ._models_py3 import ApiPortalInstance
from ._models_py3 import ApiPortalProperties
from ._models_py3 import ApiPortalResource
from ._models_py3 import ApiPortalResourceCollection
from ._models_py3 import ApiPortalResourceRequests
from ._models_py3 import ApmProperties
from ._models_py3 import ApmReference
from ._models_py3 import ApmResource
from ._models_py3 import ApmResourceCollection
from ._models_py3 import ApmSecretKeys
from ._models_py3 import AppResource
from ._models_py3 import AppResourceCollection
from ._models_py3 import AppResourceProperties
from ._models_py3 import AppVNetAddons
from ._models_py3 import ApplicationAcceleratorComponent
from ._models_py3 import ApplicationAcceleratorInstance
from ._models_py3 import ApplicationAcceleratorProperties
from ._models_py3 import ApplicationAcceleratorResource
from ._models_py3 import ApplicationAcceleratorResourceCollection
from ._models_py3 import ApplicationAcceleratorResourceRequests
from ._models_py3 import ApplicationInsightsAgentVersions
from ._models_py3 import ApplicationLiveViewComponent
from ._models_py3 import ApplicationLiveViewInstance
from ._models_py3 import ApplicationLiveViewProperties
from ._models_py3 import ApplicationLiveViewResource
from ._models_py3 import ApplicationLiveViewResourceCollection
from ._models_py3 import ApplicationLiveViewResourceRequests
from ._models_py3 import AvailableOperations
from ._models_py3 import AvailableRuntimeVersions
from ._models_py3 import AzureFileVolume
from ._models_py3 import BindingResource
from ._models_py3 import BindingResourceCollection
from ._models_py3 import BindingResourceProperties
from ._models_py3 import Build
from ._models_py3 import BuildCollection
from ._models_py3 import BuildProperties
from ._models_py3 import BuildResourceRequests
from ._models_py3 import BuildResult
from ._models_py3 import BuildResultCollection
from ._models_py3 import BuildResultLog
from ._models_py3 import BuildResultProperties
from ._models_py3 import BuildResultUserSourceInfo
from ._models_py3 import BuildService
from ._models_py3 import BuildServiceAgentPoolProperties
from ._models_py3 import BuildServiceAgentPoolResource
from ._models_py3 import BuildServiceAgentPoolResourceCollection
from ._models_py3 import BuildServiceAgentPoolSizeProperties
from ._models_py3 import BuildServiceCollection
from ._models_py3 import BuildServiceProperties
from ._models_py3 import BuildServicePropertiesResourceRequests
from ._models_py3 import BuildStageProperties
from ._models_py3 import BuilderProperties
from ._models_py3 import BuilderResource
from ._models_py3 import BuilderResourceCollection
from ._models_py3 import BuildpackBindingLaunchProperties
from ._models_py3 import BuildpackBindingProperties
from ._models_py3 import BuildpackBindingResource
from ._models_py3 import BuildpackBindingResourceCollection
from ._models_py3 import BuildpackProperties
from ._models_py3 import BuildpacksGroupProperties
from ._models_py3 import CertificateProperties
from ._models_py3 import CertificateReference
from ._models_py3 import CertificateResource
from ._models_py3 import CertificateResourceCollection
from ._models_py3 import CloudErrorBody
from ._models_py3 import ClusterResourceProperties
from ._models_py3 import ConfigServerGitProperty
from ._models_py3 import ConfigServerProperties
from ._models_py3 import ConfigServerResource
from ._models_py3 import ConfigServerSettings
from ._models_py3 import ConfigServerSettingsErrorRecord
from ._models_py3 import ConfigServerSettingsValidateResult
from ._models_py3 import ConfigurationServiceGitProperty
from ._models_py3 import ConfigurationServiceGitPropertyValidateResult
from ._models_py3 import ConfigurationServiceGitRepository
from ._models_py3 import ConfigurationServiceInstance
from ._models_py3 import ConfigurationServiceProperties
from ._models_py3 import ConfigurationServiceResource
from ._models_py3 import ConfigurationServiceResourceCollection
from ._models_py3 import ConfigurationServiceResourceRequests
from ._models_py3 import ConfigurationServiceSettings
from ._models_py3 import ConfigurationServiceSettingsValidateResult
from ._models_py3 import ContainerProbeSettings
from ._models_py3 import ContainerRegistryBasicCredentials
from ._models_py3 import ContainerRegistryCredentials
from ._models_py3 import ContainerRegistryProperties
from ._models_py3 import ContainerRegistryResource
from ._models_py3 import ContainerRegistryResourceCollection
from ._models_py3 import ContainerRegistryValidateResult
from ._models_py3 import ContentCertificateProperties
from ._models_py3 import CustomContainer
from ._models_py3 import CustomContainerUserSourceInfo
from ._models_py3 import CustomDomainProperties
from ._models_py3 import CustomDomainResource
from ._models_py3 import CustomDomainResourceCollection
from ._models_py3 import CustomDomainValidatePayload
from ._models_py3 import CustomDomainValidateResult
from ._models_py3 import CustomPersistentDiskProperties
from ._models_py3 import CustomPersistentDiskResource
from ._models_py3 import CustomizedAcceleratorProperties
from ._models_py3 import CustomizedAcceleratorResource
from ._models_py3 import CustomizedAcceleratorResourceCollection
from ._models_py3 import CustomizedAcceleratorValidateResult
from ._models_py3 import DeploymentInstance
from ._models_py3 import DeploymentList
from ._models_py3 import DeploymentResource
from ._models_py3 import DeploymentResourceCollection
from ._models_py3 import DeploymentResourceProperties
from ._models_py3 import DeploymentSettings
from ._models_py3 import DevToolPortalComponent
from ._models_py3 import DevToolPortalFeatureDetail
from ._models_py3 import DevToolPortalFeatureSettings
from ._models_py3 import DevToolPortalInstance
from ._models_py3 import DevToolPortalProperties
from ._models_py3 import DevToolPortalResource
from ._models_py3 import DevToolPortalResourceCollection
from ._models_py3 import DevToolPortalResourceRequests
from ._models_py3 import DevToolPortalSsoProperties
from ._models_py3 import DiagnosticParameters
from ._models_py3 import Error
from ._models_py3 import ExecAction
from ._models_py3 import GatewayApiMetadataProperties
from ._models_py3 import GatewayApiRoute
from ._models_py3 import GatewayCorsProperties
from ._models_py3 import GatewayCustomDomainProperties
from ._models_py3 import GatewayCustomDomainResource
from ._models_py3 import GatewayCustomDomainResourceCollection
from ._models_py3 import GatewayInstance
from ._models_py3 import GatewayOperatorProperties
from ._models_py3 import GatewayOperatorResourceRequests
from ._models_py3 import GatewayProperties
from ._models_py3 import GatewayPropertiesClientAuth
from ._models_py3 import GatewayPropertiesEnvironmentVariables
from ._models_py3 import GatewayResource
from ._models_py3 import GatewayResourceCollection
from ._models_py3 import GatewayResourceRequests
from ._models_py3 import GatewayRouteConfigOpenApiProperties
from ._models_py3 import GatewayRouteConfigProperties
from ._models_py3 import GatewayRouteConfigResource
from ._models_py3 import GatewayRouteConfigResourceCollection
from ._models_py3 import GitPatternRepository
from ._models_py3 import GloballyEnabledApms
from ._models_py3 import HTTPGetAction
from ._models_py3 import ImageRegistryCredential
from ._models_py3 import IngressConfig
from ._models_py3 import IngressSettings
from ._models_py3 import IngressSettingsClientAuth
from ._models_py3 import JarUploadedUserSourceInfo
from ._models_py3 import KeyVaultCertificateProperties
from ._models_py3 import LoadedCertificate
from ._models_py3 import LogFileUrlResponse
from ._models_py3 import LogSpecification
from ._models_py3 import ManagedIdentityProperties
from ._models_py3 import MarketplaceResource
from ._models_py3 import MetricDimension
from ._models_py3 import MetricSpecification
from ._models_py3 import MonitoringSettingProperties
from ._models_py3 import MonitoringSettingResource
from ._models_py3 import NameAvailability
from ._models_py3 import NameAvailabilityParameters
from ._models_py3 import NetCoreZipUploadedUserSourceInfo
from ._models_py3 import NetworkProfile
from ._models_py3 import NetworkProfileOutboundIPs
from ._models_py3 import OperationDetail
from ._models_py3 import OperationDisplay
from ._models_py3 import OperationProperties
from ._models_py3 import PersistentDisk
from ._models_py3 import PredefinedAcceleratorProperties
from ._models_py3 import PredefinedAcceleratorResource
from ._models_py3 import PredefinedAcceleratorResourceCollection
from ._models_py3 import Probe
from ._models_py3 import ProbeAction
from ._models_py3 import ProxyResource
from ._models_py3 import RegenerateTestKeyRequestPayload
from ._models_py3 import RemoteDebugging
from ._models_py3 import RemoteDebuggingPayload
from ._models_py3 import RequiredTraffic
from ._models_py3 import Resource
from ._models_py3 import ResourceRequests
from ._models_py3 import ResourceSku
from ._models_py3 import ResourceSkuCapabilities
from ._models_py3 import ResourceSkuCollection
from ._models_py3 import ResourceSkuLocationInfo
from ._models_py3 import ResourceSkuRestrictionInfo
from ._models_py3 import ResourceSkuRestrictions
from ._models_py3 import ResourceSkuZoneDetails
from ._models_py3 import ResourceUploadDefinition
from ._models_py3 import ServiceRegistryInstance
from ._models_py3 import ServiceRegistryProperties
from ._models_py3 import ServiceRegistryResource
from ._models_py3 import ServiceRegistryResourceCollection
from ._models_py3 import ServiceRegistryResourceRequests
from ._models_py3 import ServiceResource
from ._models_py3 import ServiceResourceList
from ._models_py3 import ServiceSpecification
from ._models_py3 import ServiceVNetAddons
from ._models_py3 import Sku
from ._models_py3 import SkuCapacity
from ._models_py3 import SkuObject
from ._models_py3 import SourceUploadedUserSourceInfo
from ._models_py3 import SsoProperties
from ._models_py3 import StackProperties
from ._models_py3 import StorageAccount
from ._models_py3 import StorageProperties
from ._models_py3 import StorageResource
from ._models_py3 import StorageResourceCollection
from ._models_py3 import SupportedApmType
from ._models_py3 import SupportedApmTypes
from ._models_py3 import SupportedBuildpackResource
from ._models_py3 import SupportedBuildpackResourceProperties
from ._models_py3 import SupportedBuildpacksCollection
from ._models_py3 import SupportedRuntimeVersion
from ._models_py3 import SupportedServerVersion
from ._models_py3 import SupportedServerVersions
from ._models_py3 import SupportedStackResource
from ._models_py3 import SupportedStackResourceProperties
from ._models_py3 import SupportedStacksCollection
from ._models_py3 import SystemData
from ._models_py3 import TCPSocketAction
from ._models_py3 import TemporaryDisk
from ._models_py3 import TestKeys
from ._models_py3 import TrackedResource
from ._models_py3 import TriggeredBuildResult
from ._models_py3 import UploadedUserSourceInfo
from ._models_py3 import UserAssignedManagedIdentity
from ._models_py3 import UserSourceInfo
from ._models_py3 import ValidationMessages
from ._models_py3 import WarUploadedUserSourceInfo

from ._app_platform_management_client_enums import ActionType
from ._app_platform_management_client_enums import ApiPortalApiTryOutEnabledState
from ._app_platform_management_client_enums import ApiPortalProvisioningState
from ._app_platform_management_client_enums import ApmProvisioningState
from ._app_platform_management_client_enums import AppResourceProvisioningState
from ._app_platform_management_client_enums import ApplicationAcceleratorProvisioningState
from ._app_platform_management_client_enums import ApplicationLiveViewProvisioningState
from ._app_platform_management_client_enums import BackendProtocol
from ._app_platform_management_client_enums import BindingType
from ._app_platform_management_client_enums import BuildProvisioningState
from ._app_platform_management_client_enums import BuildResultProvisioningState
from ._app_platform_management_client_enums import BuildServiceProvisioningState
from ._app_platform_management_client_enums import BuilderProvisioningState
from ._app_platform_management_client_enums import BuildpackBindingProvisioningState
from ._app_platform_management_client_enums import CertificateResourceProvisioningState
from ._app_platform_management_client_enums import ConfigServerState
from ._app_platform_management_client_enums import ConfigurationServiceGeneration
from ._app_platform_management_client_enums import ConfigurationServiceProvisioningState
from ._app_platform_management_client_enums import ContainerRegistryProvisioningState
from ._app_platform_management_client_enums import CreatedByType
from ._app_platform_management_client_enums import CustomDomainResourceProvisioningState
from ._app_platform_management_client_enums import CustomizedAcceleratorProvisioningState
from ._app_platform_management_client_enums import CustomizedAcceleratorType
from ._app_platform_management_client_enums import CustomizedAcceleratorValidateResultState
from ._app_platform_management_client_enums import DeploymentResourceProvisioningState
from ._app_platform_management_client_enums import DeploymentResourceStatus
from ._app_platform_management_client_enums import DevToolPortalFeatureState
from ._app_platform_management_client_enums import DevToolPortalProvisioningState
from ._app_platform_management_client_enums import GatewayCertificateVerification
from ._app_platform_management_client_enums import GatewayProvisioningState
from ._app_platform_management_client_enums import GatewayRouteConfigProtocol
from ._app_platform_management_client_enums import GitImplementation
from ._app_platform_management_client_enums import HTTPSchemeType
from ._app_platform_management_client_enums import KPackBuildStageProvisioningState
from ._app_platform_management_client_enums import KeyVaultCertificateAutoSync
from ._app_platform_management_client_enums import LastModifiedByType
from ._app_platform_management_client_enums import ManagedIdentityType
from ._app_platform_management_client_enums import MonitoringSettingState
from ._app_platform_management_client_enums import PowerState
from ._app_platform_management_client_enums import PredefinedAcceleratorProvisioningState
from ._app_platform_management_client_enums import PredefinedAcceleratorState
from ._app_platform_management_client_enums import ProbeActionType
from ._app_platform_management_client_enums import ProvisioningState
from ._app_platform_management_client_enums import ResourceSkuRestrictionsReasonCode
from ._app_platform_management_client_enums import ResourceSkuRestrictionsType
from ._app_platform_management_client_enums import ServiceRegistryProvisioningState
from ._app_platform_management_client_enums import SessionAffinity
from ._app_platform_management_client_enums import SkuScaleType
from ._app_platform_management_client_enums import StorageType
from ._app_platform_management_client_enums import SupportedRuntimePlatform
from ._app_platform_management_client_enums import SupportedRuntimeValue
from ._app_platform_management_client_enums import TestKeyType
from ._app_platform_management_client_enums import TrafficDirection
from ._app_platform_management_client_enums import TriggeredBuildResultProvisioningState
from ._app_platform_management_client_enums import Type
from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AcceleratorAuthSetting",
    "AcceleratorBasicAuthSetting",
    "AcceleratorGitRepository",
    "AcceleratorPublicSetting",
    "AcceleratorSshSetting",
    "ActiveDeploymentCollection",
    "ApiPortalCustomDomainProperties",
    "ApiPortalCustomDomainResource",
    "ApiPortalCustomDomainResourceCollection",
    "ApiPortalInstance",
    "ApiPortalProperties",
    "ApiPortalResource",
    "ApiPortalResourceCollection",
    "ApiPortalResourceRequests",
    "ApmProperties",
    "ApmReference",
    "ApmResource",
    "ApmResourceCollection",
    "ApmSecretKeys",
    "AppResource",
    "AppResourceCollection",
    "AppResourceProperties",
    "AppVNetAddons",
    "ApplicationAcceleratorComponent",
    "ApplicationAcceleratorInstance",
    "ApplicationAcceleratorProperties",
    "ApplicationAcceleratorResource",
    "ApplicationAcceleratorResourceCollection",
    "ApplicationAcceleratorResourceRequests",
    "ApplicationInsightsAgentVersions",
    "ApplicationLiveViewComponent",
    "ApplicationLiveViewInstance",
    "ApplicationLiveViewProperties",
    "ApplicationLiveViewResource",
    "ApplicationLiveViewResourceCollection",
    "ApplicationLiveViewResourceRequests",
    "AvailableOperations",
    "AvailableRuntimeVersions",
    "AzureFileVolume",
    "BindingResource",
    "BindingResourceCollection",
    "BindingResourceProperties",
    "Build",
    "BuildCollection",
    "BuildProperties",
    "BuildResourceRequests",
    "BuildResult",
    "BuildResultCollection",
    "BuildResultLog",
    "BuildResultProperties",
    "BuildResultUserSourceInfo",
    "BuildService",
    "BuildServiceAgentPoolProperties",
    "BuildServiceAgentPoolResource",
    "BuildServiceAgentPoolResourceCollection",
    "BuildServiceAgentPoolSizeProperties",
    "BuildServiceCollection",
    "BuildServiceProperties",
    "BuildServicePropertiesResourceRequests",
    "BuildStageProperties",
    "BuilderProperties",
    "BuilderResource",
    "BuilderResourceCollection",
    "BuildpackBindingLaunchProperties",
    "BuildpackBindingProperties",
    "BuildpackBindingResource",
    "BuildpackBindingResourceCollection",
    "BuildpackProperties",
    "BuildpacksGroupProperties",
    "CertificateProperties",
    "CertificateReference",
    "CertificateResource",
    "CertificateResourceCollection",
    "CloudErrorBody",
    "ClusterResourceProperties",
    "ConfigServerGitProperty",
    "ConfigServerProperties",
    "ConfigServerResource",
    "ConfigServerSettings",
    "ConfigServerSettingsErrorRecord",
    "ConfigServerSettingsValidateResult",
    "ConfigurationServiceGitProperty",
    "ConfigurationServiceGitPropertyValidateResult",
    "ConfigurationServiceGitRepository",
    "ConfigurationServiceInstance",
    "ConfigurationServiceProperties",
    "ConfigurationServiceResource",
    "ConfigurationServiceResourceCollection",
    "ConfigurationServiceResourceRequests",
    "ConfigurationServiceSettings",
    "ConfigurationServiceSettingsValidateResult",
    "ContainerProbeSettings",
    "ContainerRegistryBasicCredentials",
    "ContainerRegistryCredentials",
    "ContainerRegistryProperties",
    "ContainerRegistryResource",
    "ContainerRegistryResourceCollection",
    "ContainerRegistryValidateResult",
    "ContentCertificateProperties",
    "CustomContainer",
    "CustomContainerUserSourceInfo",
    "CustomDomainProperties",
    "CustomDomainResource",
    "CustomDomainResourceCollection",
    "CustomDomainValidatePayload",
    "CustomDomainValidateResult",
    "CustomPersistentDiskProperties",
    "CustomPersistentDiskResource",
    "CustomizedAcceleratorProperties",
    "CustomizedAcceleratorResource",
    "CustomizedAcceleratorResourceCollection",
    "CustomizedAcceleratorValidateResult",
    "DeploymentInstance",
    "DeploymentList",
    "DeploymentResource",
    "DeploymentResourceCollection",
    "DeploymentResourceProperties",
    "DeploymentSettings",
    "DevToolPortalComponent",
    "DevToolPortalFeatureDetail",
    "DevToolPortalFeatureSettings",
    "DevToolPortalInstance",
    "DevToolPortalProperties",
    "DevToolPortalResource",
    "DevToolPortalResourceCollection",
    "DevToolPortalResourceRequests",
    "DevToolPortalSsoProperties",
    "DiagnosticParameters",
    "Error",
    "ExecAction",
    "GatewayApiMetadataProperties",
    "GatewayApiRoute",
    "GatewayCorsProperties",
    "GatewayCustomDomainProperties",
    "GatewayCustomDomainResource",
    "GatewayCustomDomainResourceCollection",
    "GatewayInstance",
    "GatewayOperatorProperties",
    "GatewayOperatorResourceRequests",
    "GatewayProperties",
    "GatewayPropertiesClientAuth",
    "GatewayPropertiesEnvironmentVariables",
    "GatewayResource",
    "GatewayResourceCollection",
    "GatewayResourceRequests",
    "GatewayRouteConfigOpenApiProperties",
    "GatewayRouteConfigProperties",
    "GatewayRouteConfigResource",
    "GatewayRouteConfigResourceCollection",
    "GitPatternRepository",
    "GloballyEnabledApms",
    "HTTPGetAction",
    "ImageRegistryCredential",
    "IngressConfig",
    "IngressSettings",
    "IngressSettingsClientAuth",
    "JarUploadedUserSourceInfo",
    "KeyVaultCertificateProperties",
    "LoadedCertificate",
    "LogFileUrlResponse",
    "LogSpecification",
    "ManagedIdentityProperties",
    "MarketplaceResource",
    "MetricDimension",
    "MetricSpecification",
    "MonitoringSettingProperties",
    "MonitoringSettingResource",
    "NameAvailability",
    "NameAvailabilityParameters",
    "NetCoreZipUploadedUserSourceInfo",
    "NetworkProfile",
    "NetworkProfileOutboundIPs",
    "OperationDetail",
    "OperationDisplay",
    "OperationProperties",
    "PersistentDisk",
    "PredefinedAcceleratorProperties",
    "PredefinedAcceleratorResource",
    "PredefinedAcceleratorResourceCollection",
    "Probe",
    "ProbeAction",
    "ProxyResource",
    "RegenerateTestKeyRequestPayload",
    "RemoteDebugging",
    "RemoteDebuggingPayload",
    "RequiredTraffic",
    "Resource",
    "ResourceRequests",
    "ResourceSku",
    "ResourceSkuCapabilities",
    "ResourceSkuCollection",
    "ResourceSkuLocationInfo",
    "ResourceSkuRestrictionInfo",
    "ResourceSkuRestrictions",
    "ResourceSkuZoneDetails",
    "ResourceUploadDefinition",
    "ServiceRegistryInstance",
    "ServiceRegistryProperties",
    "ServiceRegistryResource",
    "ServiceRegistryResourceCollection",
    "ServiceRegistryResourceRequests",
    "ServiceResource",
    "ServiceResourceList",
    "ServiceSpecification",
    "ServiceVNetAddons",
    "Sku",
    "SkuCapacity",
    "SkuObject",
    "SourceUploadedUserSourceInfo",
    "SsoProperties",
    "StackProperties",
    "StorageAccount",
    "StorageProperties",
    "StorageResource",
    "StorageResourceCollection",
    "SupportedApmType",
    "SupportedApmTypes",
    "SupportedBuildpackResource",
    "SupportedBuildpackResourceProperties",
    "SupportedBuildpacksCollection",
    "SupportedRuntimeVersion",
    "SupportedServerVersion",
    "SupportedServerVersions",
    "SupportedStackResource",
    "SupportedStackResourceProperties",
    "SupportedStacksCollection",
    "SystemData",
    "TCPSocketAction",
    "TemporaryDisk",
    "TestKeys",
    "TrackedResource",
    "TriggeredBuildResult",
    "UploadedUserSourceInfo",
    "UserAssignedManagedIdentity",
    "UserSourceInfo",
    "ValidationMessages",
    "WarUploadedUserSourceInfo",
    "ActionType",
    "ApiPortalApiTryOutEnabledState",
    "ApiPortalProvisioningState",
    "ApmProvisioningState",
    "AppResourceProvisioningState",
    "ApplicationAcceleratorProvisioningState",
    "ApplicationLiveViewProvisioningState",
    "BackendProtocol",
    "BindingType",
    "BuildProvisioningState",
    "BuildResultProvisioningState",
    "BuildServiceProvisioningState",
    "BuilderProvisioningState",
    "BuildpackBindingProvisioningState",
    "CertificateResourceProvisioningState",
    "ConfigServerState",
    "ConfigurationServiceGeneration",
    "ConfigurationServiceProvisioningState",
    "ContainerRegistryProvisioningState",
    "CreatedByType",
    "CustomDomainResourceProvisioningState",
    "CustomizedAcceleratorProvisioningState",
    "CustomizedAcceleratorType",
    "CustomizedAcceleratorValidateResultState",
    "DeploymentResourceProvisioningState",
    "DeploymentResourceStatus",
    "DevToolPortalFeatureState",
    "DevToolPortalProvisioningState",
    "GatewayCertificateVerification",
    "GatewayProvisioningState",
    "GatewayRouteConfigProtocol",
    "GitImplementation",
    "HTTPSchemeType",
    "KPackBuildStageProvisioningState",
    "KeyVaultCertificateAutoSync",
    "LastModifiedByType",
    "ManagedIdentityType",
    "MonitoringSettingState",
    "PowerState",
    "PredefinedAcceleratorProvisioningState",
    "PredefinedAcceleratorState",
    "ProbeActionType",
    "ProvisioningState",
    "ResourceSkuRestrictionsReasonCode",
    "ResourceSkuRestrictionsType",
    "ServiceRegistryProvisioningState",
    "SessionAffinity",
    "SkuScaleType",
    "StorageType",
    "SupportedRuntimePlatform",
    "SupportedRuntimeValue",
    "TestKeyType",
    "TrafficDirection",
    "TriggeredBuildResultProvisioningState",
    "Type",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()
